Jupyter Notebook
================

Since alkymi is 100% Python based (and doesn't require external tools or calls from the command line), it works out of
the box in all the places where you normally run Python. Jupyter notebooks are no exception - caching and lazy
evaluation work as you would expect.
